==> bacula-1.39.34.tar.gz: bacula-1.39.34/src/win32/libwin32/winabout.h <==
/*
   This file was inspired by the VNC Win32 code by ATT

   Kern E. Sibbald, 2000
*/
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2000-2006 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation plus additions
   that are listed in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of John Walker.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/


/* Object implementing the About dialog for Bacula */

class bacAbout;

#ifndef _WINABOUT_H_
#define _WINABOUT_H_ 1

/* Define the bacAbout class */
class bacAbout
{
public:
   bacAbout();
  ~bacAbout();

   /* The dialog box window proc */
   static BOOL CALLBACK DialogProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lParam);

   void Show(BOOL show);

   /* Object local storage */
   bool visible;
};

#endif

==> bacula-2.2.0.tar.gz: bacula-2.2.0/src/win32/libwin32/winabout.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2000-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation and included
   in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of John Walker.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
   This file was inspired by the VNC Win32 code by ATT

   Kern E. Sibbald, 2000
*/


/* Header for the About dialog for Bacula */

class bacAbout;

#ifndef _WINABOUT_H_
#define _WINABOUT_H_ 1

/* Define the bacAbout class */
class bacAbout
{
public:
   bacAbout();
  ~bacAbout();

   /* The dialog box window proc */
   static BOOL CALLBACK DialogProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lParam);

   void Show(BOOL show);

   bool visible;
};

#endif
